RPM Package Manager, CVS Repository
http://rpm5.org/cvs/
____________________________________________________________________________
Server: rpm5.org Name: Jeff Johnson
Root: /v/rpm/cvs Email: jbj@rpm5.org
Module: rpm Date: 22-Nov-2007 19:50:28
Branch: HEAD Handle: 2007112218502404
Modified files:
rpm CHANGES
rpm/build pack.c parseChangelog.c
rpm/lib depends.c fsm.c package.c poptI.c query.c rpmal.c
rpmchecksig.c rpmds.c rpmds.h rpmfc.c rpmfc.h
transaction.c verify.c
rpm/python header-py.c rpmts-py.c
rpm/rpmdb dbconfig.c hdrfmt.c header.c header.h
header_internal.c header_internal.h pkgio.c
rpmdb.c rpmwf.c sqlite.c
rpm/tools rpmcache.c
Log:
- eliminate rpm peculier int typedefs, use stdint types instead.
- convert all remaining uses of int_XY to stdint types.
- revert HEADER_XARALLOCATED gloopiness.
Summary:
Revision Changes Path
1.1867 +3 -0 rpm/CHANGES
2.254 +6 -5 rpm/build/pack.c
2.36 +1 -1 rpm/build/parseChangelog.c
1.363 +15 -15 rpm/lib/depends.c
2.136 +1 -1 rpm/lib/fsm.c
2.190 +4 -4 rpm/lib/package.c
2.39 +2 -2 rpm/lib/poptI.c
2.192 +3 -3 rpm/lib/query.c
2.64 +8 -8 rpm/lib/rpmal.c
1.193 +2 -2 rpm/lib/rpmchecksig.c
2.82 +9 -9 rpm/lib/rpmds.c
2.64 +3 -3 rpm/lib/rpmds.h
1.39 +3 -3 rpm/lib/rpmfc.c
1.6 +1 -1 rpm/lib/rpmfc.h
1.354 +20 -20 rpm/lib/transaction.c
2.177 +2 -2 rpm/lib/verify.c
1.80 +6 -6 rpm/python/header-py.c
1.78 +6 -6 rpm/python/rpmts-py.c
1.51 +2 -2 rpm/rpmdb/dbconfig.c
1.36 +1 -1 rpm/rpmdb/hdrfmt.c
1.124 +15 -19 rpm/rpmdb/header.c
1.68 +0 -12 rpm/rpmdb/header.h
1.17 +2 -2 rpm/rpmdb/header_internal.c
1.34 +1 -2 rpm/rpmdb/header_internal.h
1.53 +1 -1 rpm/rpmdb/pkgio.c
1.217 +4 -4 rpm/rpmdb/rpmdb.c
1.15 +1 -1 rpm/rpmdb/rpmwf.c
1.25 +3 -3 rpm/rpmdb/sqlite.c
2.23 +1 -1 rpm/tools/rpmcache.c
____________________________________________________________________________
patch -p0 <<'@@ .'
Index: rpm/CHANGES
============================================================================
$ cvs diff -u -r1.1866 -r1.1867 CHANGES
--- rpm/CHANGES 22 Nov 2007 17:55:28 -0000 1.1866
+++ rpm/CHANGES 22 Nov 2007 18:50:24 -0000 1.1867
@@ -1,4 +1,7 @@
5.0a2 -> 5.0a3:
+ - jbj: eliminate rpm peculier int typedefs, use stdint types instead.
+ - jbj: convert all remaining uses of int_XY to stdint types.
+ - jbj: revert HEADER_XARALLOCATED gloopiness.
- jbj: functional (and leak free) -Kvv of both *.rpm and *.xar.
- jbj: revert xar handling to rpmio model, buffer handling in rpmxar.
- jbj: fix: add RPMRC_FAIL where needed using -Kvv.
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/pack.c
============================================================================
$ cvs diff -u -r2.253 -r2.254 pack.c
--- rpm/build/pack.c 20 Nov 2007 22:39:00 -0000 2.253
+++ rpm/build/pack.c 22 Nov 2007 18:50:25 -0000 2.254
@@ -602,7 +602,7 @@
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
FD_t fd = NULL;
FD_t ifd = NULL;
- int_32 count;
+ uint32_t count;
uint32_t sigtag;
const char * sigtarget;
const char * rpmio_flags = NULL;
@@ -887,14 +887,16 @@
}
/* Write the payload into the package. */
- while ((count = Fread(buf, sizeof(buf[0]), sizeof(buf), ifd)) > 0) {
- if (count == -1) {
+ while ((xx = Fread(buf, sizeof(buf[0]), sizeof(buf), ifd)) > 0) {
+ if (xx <= -1 || Ferror(ifd)) {
rpmlog(RPMLOG_ERR, _("Unable to read payload from %s: %s\n"),
sigtarget, Fstrerror(ifd));
rc = RPMRC_FAIL;
goto exit;
}
- if (Fwrite(buf, sizeof(buf[0]), count, fd) != count) {
+ count = (uint32_t) xx;
+ xx = Fwrite(buf, sizeof(buf[0]), count, fd);
+ if ((uint32_t)xx != count || Ferror(fd)) {
rpmlog(RPMLOG_ERR, _("Unable to write payload to %s: %s\n"),
fileName, Fstrerror(fd));
rc = RPMRC_FAIL;
@@ -909,7 +911,6 @@
/* XXX Fish the pkgid out of the signature header. */
if (sigh != NULL && pkgidp != NULL) {
- int xx;
he->tag = RPMSIGTAG_MD5;
xx = hge(sigh, he, 0);
if (he->t == RPM_BIN_TYPE && he->p.ptr != NULL && he->c == 16)
@@ .
patch -p0 <<'@@ .'
Index: rpm/build/parseChangelog.c
============================================================================
$ cvs diff -u -r2.35 -r2.36 parseChangelog.c
--- rpm/build/parseChangelog.c 8 Nov 2007 15:15:38 -0000 2.35
+++ rpm/build/parseChangelog.c 22 Nov 2007 18:50:25 -0000 2.36
@@ -16,7 +16,7 @@
{
HAE_t hae = headerAddExtension;
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
- uint32_t mytime = time; /* XXX convert to int_32 for header */
+ uint32_t mytime = time; /* XXX convert to uint32_t for header */
int xx;
he->tag = RPMTAG_CHANGELOGTIME;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/fsm.c
============================================================================
$ cvs diff -u -r2.135 -r2.136 fsm.c
--- rpm/lib/fsm.c 19 Nov 2007 18:57:54 -0000 2.135
+++ rpm/lib/fsm.c 22 Nov 2007 18:50:25 -0000 2.136
@@ -759,7 +759,7 @@
mode_t perms = (S_ISDIR(st->st_mode) ? fi->dperms : fi->fperms);
mode_t finalMode = (fi->fmodes ? fi->fmodes[i] : perms);
dev_t finalRdev = (fi->frdevs ? fi->frdevs[i] : 0);
- int_32 finalMtime = (fi->fmtimes ? fi->fmtimes[i] : 0);
+ uint32_t finalMtime = (fi->fmtimes ? fi->fmtimes[i] : 0);
uid_t uid = fi->uid;
gid_t gid = fi->gid;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/package.c
============================================================================
$ cvs diff -u -r2.189 -r2.190 package.c
--- rpm/lib/package.c 20 Nov 2007 22:39:00 -0000 2.189
+++ rpm/lib/package.c 22 Nov 2007 18:50:25 -0000 2.190
@@ -250,8 +250,8 @@
goto exit;
}
{ void * uh = NULL;
- int_32 uht;
- int_32 uhc;
+ rpmTagType uht;
+ rpmTagCount uhc;
unsigned char * hmagic = NULL;
size_t nmagic = 0;
@@ -289,8 +289,8 @@
/*@fallthrough@*/
case RPMSIGTAG_SHA1:
{ void * uh = NULL;
- int_32 uht;
- int_32 uhc;
+ rpmTagType uht;
+ rpmTagCount uhc;
unsigned char * hmagic = NULL;
size_t nmagic = 0;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/poptI.c
============================================================================
$ cvs diff -u -r2.38 -r2.39 poptI.c
--- rpm/lib/poptI.c 11 Oct 2007 19:44:22 -0000 2.38
+++ rpm/lib/poptI.c 22 Nov 2007 18:50:25 -0000 2.39
@@ -102,7 +102,7 @@
} break;
case POPT_ROLLBACK_EXCLUDE:
- { int_32 tid;
+ { uint32_t tid;
char *t, *te;
/* Make sure we were given the proper number of args */
@@ -121,7 +121,7 @@
/* Convert arg to TID which happens to be time_t */
/* XXX: Need check for arg to be an integer */
- tid = (int_32) strtol(t, NULL, 0);
+ tid = (uint32_t) strtol(t, NULL, 0);
/* Allocate space for new exclude tid */
ia->rbtidExcludes = xrealloc(ia->rbtidExcludes,
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/query.c
============================================================================
$ cvs diff -u -r2.191 -r2.192 query.c
--- rpm/lib/query.c 15 Nov 2007 20:26:04 -0000 2.191
+++ rpm/lib/query.c 22 Nov 2007 18:50:25 -0000 2.192
@@ -40,7 +40,7 @@
char sizefield[15];
char ownerfield[8+1], groupfield[8+1];
char timefield[100];
- time_t when = mtime; /* important if sizeof(int_32) ! sizeof(time_t) */
+ time_t when = mtime; /* important if sizeof(uint32_t) ! sizeof(time_t) */
struct tm * tm;
static time_t now;
static struct tm nowtm;
@@ -200,7 +200,7 @@
const char * fuser;
const char * fgroup;
const char * flink;
- int_32 fnlink;
+ uint32_t fnlink;
fflags = rpmfiFFlags(fi);
fmode = rpmfiFMode(fi);
@@ -512,7 +512,7 @@
case RPMQV_PKGID:
{ unsigned char MD5[16];
unsigned char * t;
- int_32 tag;
+ uint32_t tag;
for (i = 0, s = arg; *s && isxdigit(*s); s++, i++)
{};
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmal.c
============================================================================
$ cvs diff -u -r2.63 -r2.64 rpmal.c
--- rpm/lib/rpmal.c 19 Nov 2007 18:57:54 -0000 2.63
+++ rpm/lib/rpmal.c 22 Nov 2007 18:50:25 -0000 2.64
@@ -37,7 +37,7 @@
/*@refcounted@*/ /*@null@*/
rpmfi fi; /*!< File info set. */
- uint_32 tscolor; /*!< Transaction color bits. */
+ uint32_t tscolor; /*!< Transaction color bits. */
/*@exposed@*/ /*@dependent@*/ /*@null@*/
fnpyKey key; /*!< Associated file name/python object */
@@ -86,7 +86,7 @@
const char * baseName; /*!< File basename. */
int baseNameLen;
alNum pkgNum; /*!< Containing package index. */
- uint_32 ficolor;
+ uint32_t ficolor;
};
typedef /*@abstract@*/ struct dirInfo_s * dirInfo;
@@ -114,7 +114,7 @@
int delta; /*!< Delta for pkg list reallocation. */
int size; /*!< No. of pkgs in list. */
int alloced; /*!< No. of pkgs allocated for list. */
- uint_32 tscolor; /*!< Transaction color. */
+ uint32_t tscolor; /*!< Transaction color. */
int numDirs; /*!< No. of directories. */
/*@owned@*/ /*@null@*/
dirInfo dirs; /*!< Set of directories. */
@@ -416,7 +416,7 @@
}
alKey rpmalAdd(rpmal * alistp, alKey pkgKey, fnpyKey key,
- rpmds provides, rpmfi fi, uint_32 tscolor)
+ rpmds provides, rpmfi fi, uint32_t tscolor)
{
alNum pkgNum;
rpmal al;
@@ -611,9 +611,9 @@
return strcmp(a->entry, b->entry);
}
-void rpmalAddProvides(rpmal al, alKey pkgKey, rpmds provides, uint_32 tscolor)
+void rpmalAddProvides(rpmal al, alKey pkgKey, rpmds provides, uint32_t tscolor)
{
- uint_32 dscolor;
+ uint32_t dscolor;
const char * Name;
alNum pkgNum = alKey2Num(al, pkgKey);
availableIndex ai = &al->index;
@@ -686,8 +686,8 @@
fnpyKey *
rpmalAllFileSatisfiesDepend(const rpmal al, const rpmds ds, alKey * keyp)
{
- uint_32 tscolor;
- uint_32 ficolor;
+ uint32_t tscolor;
+ uint32_t ficolor;
int found = 0;
const char * dirName;
const char * baseName;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmchecksig.c
============================================================================
$ cvs diff -u -r1.192 -r1.193 rpmchecksig.c
--- rpm/lib/rpmchecksig.c 22 Nov 2007 17:55:29 -0000 1.192
+++ rpm/lib/rpmchecksig.c 22 Nov 2007 18:50:25 -0000 1.193
@@ -187,7 +187,7 @@
FD_t fd = NULL;
FD_t ofd = NULL;
struct rpmlead *lead = NULL;
- int_32 sigtag;
+ uint32_t sigtag;
const char *sigtarget = NULL;
char tmprpm[1024+1];
Header sigh = NULL;
@@ -201,7 +201,7 @@
if (argv)
{ /* start-of-arg-iteration */
- int tag = (qva->qva_source == RPMQV_FTSWALK)
+ uint32_t tag = (qva->qva_source == RPMQV_FTSWALK)
? RPMDBI_FTSWALK : RPMDBI_ARGLIST;
rpmgiFlags _giFlags = RPMGI_NONE;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmds.c
============================================================================
$ cvs diff -u -r2.81 -r2.82 rpmds.c
--- rpm/lib/rpmds.c 19 Nov 2007 18:57:54 -0000 2.81
+++ rpm/lib/rpmds.c 22 Nov 2007 18:50:25 -0000 2.82
@@ -764,9 +764,9 @@
return oEVRcmp;
}
-uint_32 rpmdsColor(const rpmds ds)
+uint32_t rpmdsColor(const rpmds ds)
{
- uint_32 Color = 0;
+ uint32_t Color = 0;
if (ds != NULL && ds->i >= 0 && ds->i < ds->Count) {
if (ds->Color != NULL)
@@ -775,9 +775,9 @@
return Color;
}
-uint_32 rpmdsSetColor(const rpmds ds, uint_32 color)
+uint32_t rpmdsSetColor(const rpmds ds, uint32_t color)
{
- uint_32 ocolor = 0;
+ uint32_t ocolor = 0;
if (ds == NULL)
return ocolor;
@@ -824,9 +824,9 @@
return orefs;
}
-int_32 rpmdsResult(const rpmds ds)
+int32_t rpmdsResult(const rpmds ds)
{
- int_32 result = 0;
+ int32_t result = 0;
if (ds != NULL && ds->i >= 0 && ds->i < ds->Count) {
if (ds->Result != NULL)
@@ -835,9 +835,9 @@
return result;
}
-int_32 rpmdsSetResult(const rpmds ds, int_32 result)
+int32_t rpmdsSetResult(const rpmds ds, int32_t result)
{
- int_32 oresult = 0;
+ int32_t oresult = 0;
if (ds == NULL)
return oresult;
@@ -1380,7 +1380,7 @@
#endif
{ "rpmlib(HeaderTagTypeInt64)", "4.4.3-1",
( RPMSENSE_EQUAL),
- N_("header tags can be type int_64.") },
+ N_("header tag data can be of type uint64_t.") },
{ "rpmlib(PayloadIsUstar)", "4.4.4-1",
(RPMSENSE_RPMLIB|RPMSENSE_EQUAL),
N_("package payload can be in ustar tar archive format.") },
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmds.h
============================================================================
$ cvs diff -u -r2.63 -r2.64 rpmds.h
--- rpm/lib/rpmds.h 19 Nov 2007 18:57:54 -0000 2.63
+++ rpm/lib/rpmds.h 22 Nov 2007 18:50:25 -0000 2.64
@@ -50,7 +50,7 @@
/*@only@*/ /*@null@*/
uint32_t * Refs; /*!< No. of file refs. */
/*@only@*/ /*@null@*/
- int_32 * Result; /*!< Dependency check result. */
+ int32_t * Result; /*!< Dependency check result. */
/*@null@*/
int (*EVRparse) (const char *evrstr, EVR_t evr); /* EVR parsing. */
int (*EVRcmp) (const char *a, const char *b); /* EVR comparison. */
@@ -402,7 +402,7 @@
* @param ds dependency set
* @return current dependency result (0 if not set)
*/
-int_32 rpmdsResult(/*@null@*/ const rpmds ds)
+int32_t rpmdsResult(/*@null@*/ const rpmds ds)
/*@*/;
/**
@@ -411,7 +411,7 @@
* @param result new dependency result
* @return previous dependency result
*/
-int_32 rpmdsSetResult(/*@null@*/ const rpmds ds, int_32 result)
+int32_t rpmdsSetResult(/*@null@*/ const rpmds ds, int32_t result)
/*@modifies ds @*/;
/**
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmfc.c
============================================================================
$ cvs diff -u -r1.38 -r1.39 rpmfc.c
--- rpm/lib/rpmfc.c 19 Nov 2007 18:57:54 -0000 1.38
+++ rpm/lib/rpmfc.c 22 Nov 2007 18:50:25 -0000 1.39
@@ -966,7 +966,7 @@
return 0;
}
-int rpmfcClassify(rpmfc fc, ARGV_t argv, int_16 * fmode)
+int rpmfcClassify(rpmfc fc, ARGV_t argv, uint16_t * fmode)
{
ARGV_t fcav = NULL;
ARGV_t dav;
@@ -999,7 +999,7 @@
for (fc->ix = 0; fc->ix < fc->nfiles; fc->ix++) {
const char * ftype;
int freeftype;
- int_16 mode = (fmode ? fmode[fc->ix] : 0);
+ uint16_t mode = (fmode ? fmode[fc->ix] : 0);
int urltype;
ftype = ""; freeftype = 0;
@@ -1403,7 +1403,7 @@
rpmds ds;
int flags = 0x2; /* XXX no filtering, !scareMem */
ARGV_t av;
- int_16 * fmode;
+ uint16_t * fmode;
int ac = rpmfiFC(fi);
char buf[BUFSIZ];
const char * N;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/rpmfc.h
============================================================================
$ cvs diff -u -r1.5 -r1.6 rpmfc.h
--- rpm/lib/rpmfc.h 14 Jul 2007 03:22:44 -0000 1.5
+++ rpm/lib/rpmfc.h 22 Nov 2007 18:50:25 -0000 1.6
@@ -178,7 +178,7 @@
* @return 0 on success
*/
/*@-exportlocal@*/
-int rpmfcClassify(rpmfc fc, ARGV_t argv, /*@null@*/ int16_t * fmode)
+int rpmfcClassify(rpmfc fc, ARGV_t argv, /*@null@*/ uint16_t * fmode)
/*@globals rpmGlobalMacroContext, h_errno, fileSystem, internalState @*/
/*@modifies fc, rpmGlobalMacroContext, fileSystem, internalState @*/;
/*@=exportlocal@*/
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/transaction.c
============================================================================
$ cvs diff -u -r1.353 -r1.354 transaction.c
--- rpm/lib/transaction.c 19 Nov 2007 18:57:54 -0000 1.353
+++ rpm/lib/transaction.c 22 Nov 2007 18:50:25 -0000 1.354
@@ -91,11 +91,11 @@
HGE_t hge = headerGetExtension;
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
const char * altNVRA = NULL;
- uint_32 tscolor = rpmtsColor(ts);
- uint_32 prefcolor = rpmtsPrefColor(ts);
- uint_32 otecolor, tecolor;
- uint_32 oFColor, FColor;
- uint_32 oFFlags, FFlags;
+ uint32_t tscolor = rpmtsColor(ts);
+ uint32_t prefcolor = rpmtsPrefColor(ts);
+ uint32_t otecolor, tecolor;
+ uint32_t oFColor, FColor;
+ uint32_t oFFlags, FFlags;
rpmfi otherFi = NULL;
rpmps ps;
int xx;
@@ -163,7 +163,7 @@
/* Remove setuid/setgid bits on other (possibly hardlinked) files. */
if (!(fi->mapflags & CPIO_SBIT_CHECK)) {
- int_16 omode = rpmfiFMode(otherFi);
+ uint16_t omode = rpmfiFMode(otherFi);
if (S_ISREG(omode) && (omode & 06000) != 0)
fi->mapflags |= CPIO_SBIT_CHECK;
}
@@ -369,7 +369,7 @@
/*@globals h_errno, fileSystem, internalState @*/
/*@modifies ts, fi, fileSystem, internalState @*/
{
- uint_32 fixupSize = 0;
+ uint32_t fixupSize = 0;
rpmps ps;
const char * fn;
int i, j;
@@ -378,14 +378,14 @@
fi = rpmfiInit(fi, 0);
if (fi != NULL)
while ((i = rpmfiNext(fi)) >= 0) {
- uint_32 tscolor = rpmtsColor(ts);
- uint_32 prefcolor = rpmtsPrefColor(ts);
- uint_32 oFColor, FColor;
+ uint32_t tscolor = rpmtsColor(ts);
+ uint32_t prefcolor = rpmtsPrefColor(ts);
+ uint32_t oFColor, FColor;
struct fingerPrint_s * fiFps;
int otherPkgNum, otherFileNum;
rpmfi otherFi;
- int_32 FFlags;
- int_16 FMode;
+ uint32_t FFlags;
+ uint16_t FMode;
const rpmfi * recs;
int numRecs;
@@ -600,7 +600,7 @@
{
HGE_t hge = headerGetExtension;
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
- int_32 reqFlags = (RPMSENSE_LESS | RPMSENSE_EQUAL);
+ uint32_t reqFlags = (RPMSENSE_LESS | RPMSENSE_EQUAL);
const char * reqEVR;
rpmds req;
char * t;
@@ -654,8 +654,8 @@
/*@globals rpmGlobalMacroContext, h_errno, internalState @*/
/*@modifies fi, rpmGlobalMacroContext, internalState @*/
{
- uint_32 tscolor = rpmtsColor(ts);
- uint_32 FColor;
+ uint32_t tscolor = rpmtsColor(ts);
+ uint32_t FColor;
int noConfigs = (rpmtsFlags(ts) & RPMTRANS_FLAG_NOCONFIGS);
int noDocs = (rpmtsFlags(ts) & RPMTRANS_FLAG_NODOCS);
char ** netsharedPaths = NULL;
@@ -834,7 +834,7 @@
if (fi != NULL) /* XXX lclint */
while ((i = rpmfiNext(fi)) >= 0) {
const char * fdn, * fbn;
- int_16 fFMode;
+ uint16_t fFMode;
if (XFA_SKIPPING(fi->actions[i]))
/*@innercontinue@*/ continue;
@@ -939,7 +939,7 @@
{
const char * semfn = NULL;
rpmRC rc = 0;
- uint_32 arbgoal = rpmtsARBGoal(rbts);
+ uint32_t arbgoal = rpmtsARBGoal(rbts);
QVA_t ia = memset(alloca(sizeof(*ia)), 0, sizeof(*ia));
time_t ttid;
int xx;
@@ -1119,7 +1119,7 @@
int rpmtsRun(rpmts ts, rpmps okProbs, rpmprobFilterFlags ignoreSet)
{
- uint_32 tscolor = rpmtsColor(ts);
+ uint32_t tscolor = rpmtsColor(ts);
int i, j;
int ourrc = 0;
int totalFileCount = 0;
@@ -1206,7 +1206,7 @@
(void) rpmtsSetChrootDone(ts, 0);
/* XXX rpmtsCreate() sets the transaction id, but apps may not honor. */
- { int_32 tid = (int_32) time(NULL);
+ { uint32_t tid = (uint32_t) time(NULL);
(void) rpmtsSetTid(ts, tid);
}
@@ -1501,7 +1501,7 @@
fi = rpmfiInit(fi, 0);
while ((i = rpmfiNext(fi)) >= 0) {
struct stat sb, *st = &sb;
- uint_32 FFlags = rpmfiFFlags(fi);
+ uint32_t FFlags = rpmfiFFlags(fi);
numShared += dbiIndexSetCount(matches[i]);
if (!(FFlags & RPMFILE_CONFIG))
/*@innercontinue@*/ continue;
@@ .
patch -p0 <<'@@ .'
Index: rpm/lib/verify.c
============================================================================
$ cvs diff -u -r2.176 -r2.177 verify.c
--- rpm/lib/verify.c 15 Nov 2007 20:26:04 -0000 2.176
+++ rpm/lib/verify.c 22 Nov 2007 18:50:25 -0000 2.177
@@ -186,8 +186,8 @@
{
*res |= RPMVERIFY_RDEV;
} else if (S_ISDEV(fmode) && S_ISDEV(sb.st_mode)) {
- uint_16 st_rdev = (sb.st_rdev & 0xffff);
- uint_16 frdev = (rpmfiFRdev(fi) & 0xffff);
+ uint16_t st_rdev = (sb.st_rdev & 0xffff);
+ uint16_t frdev = (rpmfiFRdev(fi) & 0xffff);
if (st_rdev != frdev)
*res |= RPMVERIFY_RDEV;
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/python/header-py.c
============================================================================
$ cvs diff -u -r1.79 -r1.80 header-py.c
--- rpm/python/header-py.c 21 Nov 2007 00:25:04 -0000 1.79
+++ rpm/python/header-py.c 22 Nov 2007 18:50:27 -0000 1.80
@@ -137,9 +137,9 @@
char ** md5list;
char ** fileList;
char ** linkList;
- int_32 * fileSizes;
- int_32 * mtimes;
- int_32 * uids, * gids; /* XXX these tags are not used anymore */
+ uint32_t * fileSizes;
+ uint32_t * mtimes;
+ uint32_t * uids, * gids; /* XXX these tags are not used anymore */
unsigned short * rdevs;
unsigned short * modes;
} ;
@@ -367,7 +367,7 @@
{
HGE_t hge = headerGetExtension;
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
- int_32 tag = -1;
+ uint32_t tag = 0xffffffff;
int i;
PyObject * o, * metao;
int forceArray = 0;
@@ -379,7 +379,7 @@
else
tag = tagNumFromPyObject (item);
- if (tag == -1 && (PyString_Check(item) || PyUnicode_Check(item))) {
+ if (tag == 0xffffffff && (PyString_Check(item) || PyUnicode_Check(item))) {
const struct headerSprintfExtension_s * extensions = rpmHeaderFormats;
char * str;
/* if we still don't have the tag, go looking for the header
@@ -400,7 +400,7 @@
if (ext) {
ext->u.tagFunction(s->h, he);
} else {
- if (tag == -1) {
+ if (tag == 0xffffffff) {
PyErr_SetString(PyExc_KeyError, "unknown header tag");
return NULL;
}
@@ .
patch -p0 <<'@@ .'
Index: rpm/python/rpmts-py.c
============================================================================
$ cvs diff -u -r1.77 -r1.78 rpmts-py.c
--- rpm/python/rpmts-py.c 3 Nov 2007 23:44:03 -0000 1.77
+++ rpm/python/rpmts-py.c 22 Nov 2007 18:50:27 -0000 1.78
@@ -462,7 +462,7 @@
mi = rpmdbFreeIterator(mi);
} else
if (PyInt_Check(o)) {
- uint_32 instance = PyInt_AsLong(o);
+ uint32_t instance = PyInt_AsLong(o);
mi = rpmtsInitIterator(s->ts, RPMDBI_PACKAGES, &instance, sizeof(instance));
if (instance == 0 || mi == NULL) {
@@ -472,7 +472,7 @@
} else {
Header h;
while ((h = rpmdbNextIterator(mi)) != NULL) {
- uint_32 recOffset = rpmdbGetIteratorOffset(mi);
+ uint32_t recOffset = rpmdbGetIteratorOffset(mi);
if (recOffset)
rpmtsAddEraseElement(s->ts, h, recOffset);
break;
@@ -657,7 +657,7 @@
PyObject * result = NULL;
rpmTag tag = RPMTAG_INSTALLTID;
char * kwlist[] = {"rbtid", NULL};
- uint_32 rbtid = 0;
+ uint32_t rbtid = 0;
IDTX idtx;
if (_rpmts_debug)
@@ -708,7 +708,7 @@
const char * globstr;
rpmTag tag = RPMTAG_REMOVETID;
char * kwlist[] = {"rbtid", NULL};
- uint_32 rbtid = 0;
+ uint32_t rbtid = 0;
IDTX idtx;
if (_rpmts_debug)
@@ -760,7 +760,7 @@
QVA_t ia = memset(alloca(sizeof(*ia)), 0, sizeof(*ia));
rpmtransFlags transFlags;
const char ** av = NULL;
- uint_32 rbtid;
+ uint32_t rbtid;
int rc;
char * kwlist[] = {"transactionId", NULL};
@@ -1025,7 +1025,7 @@
rpmts_SetColor(rpmtsObject * s, PyObject * args, PyObject * kwds)
/*@modifies s @*/
{
- uint_32 tscolor;
+ uint32_t tscolor;
char * kwlist[] = {"color", NULL};
if (_rpmts_debug)
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/dbconfig.c
============================================================================
$ cvs diff -u -r1.50 -r1.51 dbconfig.c
--- rpm/rpmdb/dbconfig.c 19 Nov 2007 18:57:59 -0000 1.50
+++ rpm/rpmdb/dbconfig.c 22 Nov 2007 18:50:27 -0000 1.51
@@ -809,10 +809,10 @@
switch (rpmtag) {
case RPMDBI_PACKAGES:
case RPMDBI_DEPENDS:
- dbi->dbi_jlen = 1 * sizeof(int_32);
+ dbi->dbi_jlen = 1 * sizeof(uint32_t);
break;
default:
- dbi->dbi_jlen = 2 * sizeof(int_32);
+ dbi->dbi_jlen = 2 * sizeof(uint32_t);
break;
}
/*@=sizeoftype@*/
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/hdrfmt.c
============================================================================
$ cvs diff -u -r1.35 -r1.36 hdrfmt.c
--- rpm/rpmdb/hdrfmt.c 20 Nov 2007 17:37:03 -0000 1.35
+++ rpm/rpmdb/hdrfmt.c 22 Nov 2007 18:50:27 -0000 1.36
@@ -699,7 +699,7 @@
t = stpcpy(t, ", ");
- /* this is important if sizeof(int_32) ! sizeof(time_t) */
+ /* this is important if sizeof(uint32_t) ! sizeof(time_t) */
{ time_t dateint = pgpGrab(sigp->time, sizeof(sigp->time));
struct tm * tstruct = localtime(&dateint);
if (tstruct)
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/header.h
============================================================================
$ cvs diff -u -r1.67 -r1.68 header.h
--- rpm/rpmdb/header.h 21 Nov 2007 14:24:35 -0000 1.67
+++ rpm/rpmdb/header.h 22 Nov 2007 18:50:27 -0000 1.68
@@ -85,18 +85,6 @@
extern "C" {
#endif
-/* XXX hpux needs -Ae in CFLAGS to grok this */
-typedef long long int int_64;
-typedef int int_32;
-typedef short int int_16;
-typedef char int_8;
-
-/* XXX hpux needs -Ae in CFLAGS to grok this */
-typedef unsigned long long int uint_64;
-typedef unsigned int uint_32;
-typedef unsigned short uint_16;
-typedef unsigned char uint_8;
-
/** \ingroup header
*/
typedef const char * errmsg_t;
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/header_internal.c
============================================================================
$ cvs diff -u -r1.16 -r1.17 header_internal.c
--- rpm/rpmdb/header_internal.c 15 Nov 2007 23:14:53 -0000 1.16
+++ rpm/rpmdb/header_internal.c 22 Nov 2007 18:50:27 -0000 1.17
@@ -48,7 +48,7 @@
info->type = RPM_UINT8_TYPE;
pe[i].type = (uint32_t) htonl(info->type);
}
- info->offset = (int_32) ntohl(pe[i].offset);
+ info->offset = (int32_t) ntohl(pe[i].offset);
assert(negate || info->offset >= 0); /* XXX insurance */
if (negate)
info->offset = -info->offset;
@@ -58,7 +58,7 @@
return (int)i;
if (hdrchkAlign(info->type, info->offset))
return (int)i;
- if (!negate && hdrchkRange((int_32)dl, info->offset))
+ if (!negate && hdrchkRange((int32_t)dl, info->offset))
return (int)i;
if (hdrchkData(info->count))
return (int)i;
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/header_internal.h
============================================================================
$ cvs diff -u -r1.33 -r1.34 header_internal.h
--- rpm/rpmdb/header_internal.h 21 Nov 2007 21:58:47 -0000 1.33
+++ rpm/rpmdb/header_internal.h 22 Nov 2007 18:50:27 -0000 1.34
@@ -55,7 +55,7 @@
struct entryInfo_s {
uint32_t tag; /*!< Tag identifier. */
uint32_t type; /*!< Tag data type. */
- int_32 offset; /*!< Offset into data segment (ondisk only). */
+ int32_t offset; /*!< Offset into data segment (ondisk only). */
uint32_t count; /*!< Number of tag elements. */
};
@@ -102,7 +102,6 @@
#define HEADERFLAG_LEGACY (1 << 2) /*!< Header came from legacy source? */
#define HEADERFLAG_DEBUG (1 << 3) /*!< Debug this header? */
#define HEADERFLAG_SIGNATURE (1 << 4) /*!< Signature header? */
-#define HEADERFLAG_XARALLOCATED (1 << 5) /*!< Did XAR allocate the region? */
/*@refs@*/
int nrefs; /*!< Reference count. */
};
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/pkgio.c
============================================================================
$ cvs diff -u -r1.52 -r1.53 pkgio.c
--- rpm/rpmdb/pkgio.c 22 Nov 2007 17:55:29 -0000 1.52
+++ rpm/rpmdb/pkgio.c 22 Nov 2007 18:50:27 -0000 1.53
@@ -739,7 +739,7 @@
/*@=sizeoftype@*/
assert(entry->info.offset > 0); /* XXX insurance */
- if (entry->info.offset >= (int_32)dl) {
+ if (entry->info.offset >= (int32_t)dl) {
(void) snprintf(buf, sizeof(buf),
_("region offset: BAD, tag %u type %u offset %d count %u\n"),
(unsigned) entry->info.tag, (unsigned) entry->info.type,
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/rpmdb.c
============================================================================
$ cvs diff -u -r1.216 -r1.217 rpmdb.c
--- rpm/rpmdb/rpmdb.c 20 Nov 2007 18:44:24 -0000 1.216
+++ rpm/rpmdb/rpmdb.c 22 Nov 2007 18:50:27 -0000 1.217
@@ -486,7 +486,7 @@
/*@-sizeoftype @*/
switch (dbi->dbi_jlen) {
default:
- case 2*sizeof(int_32):
+ case 2*sizeof(uint32_t):
for (i = 0; i < set->count; i++) {
union _dbswap hdrNum, tagNum;
@@ -503,7 +503,7 @@
set->recs[i].fpNum = 0;
}
break;
- case 1*sizeof(int_32):
+ case 1*sizeof(uint32_t):
for (i = 0; i < set->count; i++) {
union _dbswap hdrNum;
@@ -553,7 +553,7 @@
/*@-sizeoftype@*/
switch (dbi->dbi_jlen) {
default:
- case 2*sizeof(int_32):
+ case 2*sizeof(uint32_t):
for (i = 0; i < set->count; i++) {
union _dbswap hdrNum, tagNum;
@@ -571,7 +571,7 @@
tdbir += sizeof(tagNum.ui);
}
break;
- case 1*sizeof(int_32):
+ case 1*sizeof(uint32_t):
for (i = 0; i < set->count; i++) {
union _dbswap hdrNum;
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/rpmwf.c
============================================================================
$ cvs diff -u -r1.14 -r1.15 rpmwf.c
--- rpm/rpmdb/rpmwf.c 22 Nov 2007 17:55:29 -0000 1.14
+++ rpm/rpmdb/rpmwf.c 22 Nov 2007 18:50:27 -0000 1.15
@@ -91,7 +91,7 @@
return RPMRC_OK;
}
-static size_t hSize(uint_32 *p)
+static size_t hSize(uint32_t *p)
/*@*/
{
return (8 + 8 + 16 * ntohl(p[2]) + ntohl(p[3]));
@@ .
patch -p0 <<'@@ .'
Index: rpm/rpmdb/sqlite.c
============================================================================
$ cvs diff -u -r1.24 -r1.25 sqlite.c
--- rpm/rpmdb/sqlite.c 19 Nov 2007 18:57:59 -0000 1.24
+++ rpm/rpmdb/sqlite.c 22 Nov 2007 18:50:27 -0000 1.25
@@ -512,7 +512,7 @@
switch (dbi->dbi_rpmtag) {
case RPMDBI_PACKAGES:
{ unsigned int hnum;
-/*@i@*/ assert(key->size == sizeof(int_32));
+/*@i@*/ assert(key->size == sizeof(uint32_t));
memcpy(&hnum, key->data, sizeof(hnum));
if (swapped == 1) {
@@ -538,7 +538,7 @@
} /*@innerbreak@*/ break;
case RPM_UINT16_TYPE:
{ unsigned short i;
-/*@i@*/ assert(key->size == sizeof(int_16));
+/*@i@*/ assert(key->size == sizeof(uint16_t));
assert(swapped == 0); /* Byte swap?! */
memcpy(&i, key->data, sizeof(i));
rc = sqlite3_bind_int(scp->pStmt, pos, (int) i);
@@ -549,7 +549,7 @@
case RPM_UINT32_TYPE:
default:
{ unsigned int i;
-/*@i@*/ assert(key->size == sizeof(int_32));
+/*@i@*/ assert(key->size == sizeof(uint32_t));
memcpy(&i, key->data, sizeof(i));
if (swapped == 1)
@@ .
patch -p0 <<'@@ .'
Index: rpm/tools/rpmcache.c
============================================================================
$ cvs diff -u -r2.22 -r2.23 rpmcache.c
--- rpm/tools/rpmcache.c 8 Nov 2007 15:15:41 -0000 2.22
+++ rpm/tools/rpmcache.c 22 Nov 2007 18:50:28 -0000 2.23
@@ -574,7 +574,7 @@
vsflags |= RPMVSF_NOHDRCHK;
(void) rpmtsSetVSFlags(ts, vsflags);
- { int_32 tid = (int_32) time(NULL);
+ { uint32_t tid = (uint32_t) time(NULL);
(void) rpmtsSetTid(ts, tid);
}
@@ .
Received on Thu Nov 22 19:50:28 2007
Index: rpm/lib/depends.c
============================================================================
$ cvs diff -u -r1.362 -r1.363 depends.c
--- rpm/lib/depends.c 15 Nov 2007 20:26:04 -0000 1.362
+++ rpm/lib/depends.c 22 Nov 2007 18:50:25 -0000 1.363
@@ -193,12 +193,12 @@
HGE_t hge = headerGetExtension;
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
rpmdepFlags depFlags = rpmtsDFlags(ts);
- uint_32 tscolor = rpmtsColor(ts);
- uint_32 dscolor;
- uint_32 hcolor;
+ uint32_t tscolor = rpmtsColor(ts);
+ uint32_t dscolor;
+ uint32_t hcolor;
rpmdbMatchIterator mi;
Header oh;
- uint_32 ohcolor;
+ uint32_t ohcolor;
int isSource;
int duplicate = 0;
rpmtsi pi = NULL; rpmte p;
@@ -586,7 +586,7 @@
rpmdbMatchIterator mi;
nsType NSType;
const char * Name;
- int_32 Flags;
+ uint32_t Flags;
Header h;
#if defined(CACHE_DEPENDENCY_RESULT)
int _cacheThisRC = 1;
@@ -1144,14 +1144,14 @@
/*@null@*/ rpmds conflicts,
/*@null@*/ rpmds dirnames,
/*@null@*/ rpmds linktos,
/*@null@*/ const char * depName, uint_32 tscolor, int adding)
/*@globals rpmGlobalMacroContext, h_errno,
fileSystem, internalState @*/
/*@modifies ts, requires, conflicts, dirnames, linktos,
rpmGlobalMacroContext, fileSystem, internalState */
{
rpmps ps = rpmtsProblems(ts);
- uint_32 dscolor;
+ uint32_t dscolor;
const char * Name;
int rc;
int ourrc = 0;
@@ -1332,7 +1332,7 @@
HGE_t hge = headerGetExtension;
HE_t he = memset(alloca(sizeof(*he)), 0, sizeof(*he));
rpmdepFlags depFlags = rpmtsDFlags(ts);
- uint_32 tscolor = rpmtsColor(ts);
+ uint32_t tscolor = rpmtsColor(ts);
int scareMem = 0;
Header h;
int ec = 0;
@@ -1558,7 +1558,7 @@
* @param f dependency flags
* @return display string
*/
-static inline /*@observer@*/ const char * identifyDepend(int_32 f)
+static inline /*@observer@*/ const char * identifyDepend(uint32_t f)
/*@*/
{
f = _notpre(f);
@@ -1610,7 +1610,7 @@
tsi_prev = tsi, tsi = tsi->tsi_next)
/*@=nullderef@*/
{
- int_32 Flags;
+ uint32_t Flags;
/*@-abstractcompare@*/
if (tsi->tsi_suc != p)
@@ -1782,7 +1782,7 @@
static void addQ(/*@dependent@*/ rpmte p,
/*@in@*/ /*@out@*/ rpmte * qp,
/*@in@*/ /*@out@*/ rpmte * rp,
- uint_32 prefcolor)
+ uint32_t prefcolor)
/*@modifies p, *qp, *rp @*/
{
rpmte q, qprev;
@@ -1842,9 +1842,9 @@
int rpmtsOrder(rpmts ts)
{
rpmds requires;
- int_32 Flags;
+ uint32_t Flags;
int anaconda = rpmtsDFlags(ts) & RPMDEPS_FLAG_ANACONDA;
- uint_32 prefcolor = rpmtsPrefColor(ts);
+ uint32_t prefcolor = rpmtsPrefColor(ts);
rpmtsi pi; rpmte p;
rpmtsi qi; rpmte q;
rpmtsi ri; rpmte r;
@@ -1880,7 +1880,7 @@
while ((p = rpmtsiNext(pi, TR_REMOVED)) != NULL) {
alKey pkgKey;
fnpyKey key;
- uint_32 tscolor = rpmtsColor(ts);
+ uint32_t tscolor = rpmtsColor(ts);
pkgKey = RPMAL_NOMATCH;
/*@-abstract@*/
key = (fnpyKey) p;
@@ -2316,7 +2316,7 @@
{
const char * depName = NULL;
rpmdepFlags depFlags = rpmtsDFlags(ts);
- uint_32 tscolor = rpmtsColor(ts);
+ uint32_t tscolor = rpmtsColor(ts);
rpmdbMatchIterator mi = NULL;
rpmtsi pi = NULL; rpmte p;
int closeatexit = 0;
@@ .
patch -p0 <<'@@ .'
@@ -1144,14 +1144,14 @@
/*@null@*/ rpmds dirnames,
/*@null@*/ rpmds linktos,
- /*@null@*/ const char * depName, uint_32 tscolor, int adding)
+ /*@null@*/ const char * depName, uint32_t tscolor, int adding)
/*@globals rpmGlobalMacroContext, h_errno,
fileSystem, internalState @*/
Index: rpm/rpmdb/header.c
============================================================================
$ cvs diff -u -r1.123 -r1.124 header.c
--- rpm/rpmdb/header.c 21 Nov 2007 21:58:47 -0000 1.123
+++ rpm/rpmdb/header.c 22 Nov 2007 18:50:27 -0000 1.124
@@ -266,12 +266,8 @@
if ((h->flags & HEADERFLAG_ALLOCATED) && ENTRY_IS_REGION(entry)) {
if (entry->length > 0) {
uint32_t * ei = entry->data;
- if ((ei - 2) == h->blob) {
- /* Adjust for XAR including 8b of magic. */
- if (h->flags & HEADERFLAG_XARALLOCATED)
- h->blob = &((char *)h->blob)[-8];
+ if ((ei - 2) == h->blob)
h->blob = _free(h->blob);
- }
entry->data = NULL;
}
} else if (!ENTRY_IN_REGION(entry)) {
@@ -405,7 +401,7 @@
size += sizeof(header_magic); /* XXX HEADER_MAGIC_YES */
/*@-sizeoftype@*/
- size += 2 * sizeof(int_32); /* count of index entries */
+ size += 2 * sizeof(uint32_t); /* count of index entries */
/*@=sizeoftype@*/
for (i = 0, entry = h->index; i < h->indexUsed; i++, entry++) {
@@ -507,7 +503,7 @@
}
/** \ingroup header
* Swap int_32 and int_16 arrays within header region.
*
* This code is way more twisty than I would like.
*
@@ -556,7 +552,7 @@
ie.info.tag = (uint32_t) ntohl(pe->tag);
ie.info.type = (uint32_t) ntohl(pe->type);
ie.info.count = (uint32_t) ntohl(pe->count);
- ie.info.offset = (int_32) ntohl(pe->offset);
+ ie.info.offset = (int32_t) ntohl(pe->offset);
assert(ie.info.offset >= 0); /* XXX insurance */
if (hdrchkType(ie.info.type))
@@ -718,7 +714,7 @@
if (ENTRY_IS_REGION(entry)) {
uint32_t rdl;
uint32_t ril;
- int_32 rid;
+ int32_t rid;
assert(entry->info.offset <= 0); /* XXX insurance */
rdl = -entry->info.offset; /* negative offset */
@@ -810,7 +806,7 @@
if (ENTRY_IS_REGION(entry)) {
uint32_t rdl;
uint32_t ril;
- int_32 rid;
+ int32_t rid;
assert(entry->info.offset <= 0); /* XXX insurance */
@@ -830,7 +826,7 @@
memcpy(te, src + rdl, rdlen);
te += rdlen;
- pe->offset = (int_32) htonl(te - dataStart);
+ pe->offset = (int32_t) htonl(te - dataStart);
stei[0] = (uint32_t) pe->tag;
stei[1] = (uint32_t) pe->type;
stei[2] = (uint32_t) htonl(-rdl-entry->info.count);
@@ -852,8 +848,8 @@
{ /*@-castexpose@*/
entryInfo se = (entryInfo)src;
/*@=castexpose@*/
- int_32 off = (int_32) ntohl(se->offset);
- pe->offset = (int_32)((off)
+ int32_t off = (int32_t) ntohl(se->offset);
+ pe->offset = (int32_t)((off)
? htonl(te - dataStart) : htonl(off));
}
te += entry->info.count + drlen;
@@ -890,7 +886,7 @@
}
}
- pe->offset = (int_32) htonl(te - dataStart);
+ pe->offset = (int32_t) htonl(te - dataStart);
/* copy data w/ endian conversions */
switch (entry->info.type) {
@@ -1153,7 +1149,7 @@
if (hdrchkTags(entry->info.count))
goto errxit;
- { int_32 off = (int_32) ntohl(pe->offset);
+ { int32_t off = (int32_t) ntohl(pe->offset);
if (hdrchkData(off))
goto errxit;
@@ -1163,7 +1159,7 @@
/*@=sizeoftype@*/
uint32_t * stei = memcpy(alloca(nb), dataStart + off, nb);
rdl = -ntohl(stei[2]); /* negative offset */
-assert((int_32)rdl >= 0); /* XXX insurance */
+assert((int32_t)rdl >= 0); /* XXX insurance */
ril = rdl/sizeof(*pe);
if (hdrchkTags(ril) || hdrchkData(rdl))
goto errxit;
@@ -1176,7 +1172,7 @@
entry->info.tag = HEADER_IMAGE;
}
}
- entry->info.offset = (int_32) -rdl; /* negative offset */
+ entry->info.offset = (int32_t) -rdl; /* negative offset */
/*@-assignexpose@*/
entry->data = pe;
@@ -1190,7 +1186,7 @@
if (ril < h->indexUsed) {
indexEntry newEntry = entry + ril;
size_t ne = (h->indexUsed - ril);
- int_32 rid = entry->info.offset+1;
+ int32_t rid = entry->info.offset+1;
uint32_t rc;
/* Load dribble entries from region. */
@@ -2865,7 +2861,7 @@
struct tm * tstruct;
char buf[50];
- /* this is important if sizeof(int_64) ! sizeof(time_t) */
+ /* this is important if sizeof(uint64_t) ! sizeof(time_t) */
{ time_t dateint = data.ui64p[0];
tstruct = localtime(&dateint);
}
@@ .
patch -p0 <<'@@ .'
@@ -507,7 +503,7 @@
}
/** \ingroup header
- * Swap int_32 and int_16 arrays within header region.
+ * Swap uint32_t and uint16_t arrays within header region.
*
* This code is way more twisty than I would like.